# PyWEED

[![Anaconda-Server Badge](https://anaconda.org/conda-forge/pyweed/badges/version.svg)](https://anaconda.org/conda-forge/pyweed)
[![Anaconda-Server Badge](https://anaconda.org/conda-forge/pyweed/badges/latest_release_date.svg)](https://anaconda.org/conda-forge/pyweed)
[![Anaconda-Server Badge](https://anaconda.org/conda-forge/pyweed/badges/platforms.svg)](https://anaconda.org/conda-forge/pyweed)
[![Anaconda-Server Badge](https://anaconda.org/conda-forge/pyweed/badges/license.svg)](https://anaconda.org/conda-forge/pyweed)
[![Anaconda-Server Badge](https://anaconda.org/conda-forge/pyweed/badges/downloads.svg)](https://conda.anaconda.org/conda-forge)

PyWEED is an application for retrieving event-based seismic data.

PyWEED works on Windows, Mac, and Linux (64-bit). It is built on [ObsPy](https://obspy.org/) and
[PyQt](https://pypi.python.org/pypi/PyQt5).

For documentation, see the [GitHub Pages](https://iris-edu.github.io/pyweed/).
